@@ -409,6 +409,33 @@ def create_adjusted_model_for_percentages(model_src, model_use):
         f.write(content)
 
 
+def create_pfile(input_filename, output_filename, feature_count, data):
+    """Create a pfile.
+    :param input_filename: path to a file that will be created temporarily
+    :param output_filename: name of the pfile that will be created
+    :param feature_count: dimension of all features combined
+    :type feature_count: int
+    :param data: list of (x, y) tuples, where x is the feature vector
+                 of dimension ``feature_count`` and y is a label.
+    """
+    # TODO: The input_filename should not be necessary!
+    with open(input_filename, "w") as f:
+        for symbolnr, instance in enumerate(data):
+            feature_string, label = instance
+            assert len(feature_string) == feature_count, \
+                "Expected %i features, got %i features" % \
+                (feature_count, len(feature_string))
+            feature_string = " ".join(map(str, feature_string))
+            line = "%i 0 %s %i" % (symbolnr, feature_string, label)
+            print(line, file=f)
+    command = "pfile_create -i %s -f %i -l 1 -o %s" % \
+              (input_filename, feature_count, output_filename)
+    logging.info(command)
+    os.system(command)
+    # Clean up
+    os.remove(input_filename)
+
+
 def evaluate_model(recording, model_folder, verbose=False):
     """Evaluate model for a single recording."""
     from . import preprocess_dataset
@@ -449,24 +476,10 @@ def evaluate_model(recording, model_folder, verbose=False):
             feature_count = sum(map(lambda n: n.get_dimension(),
                                     feature_list))
             x = handwriting.feature_extraction(feature_list)
+
             # Create pfile
-            input_filename = "tmp.txt"
             output_filename = "evaluate.pfile"
-            with open(input_filename, "w") as f:
-                for symbolnr, instance in enumerate([(x, 0)]):
-                    feature_string, label = instance
-                    assert len(feature_string) == feature_count, \
-                        "Expected %i features, got %i features" % \
-                        (feature_count, len(feature_string))
-                    feature_string = " ".join(map(str, feature_string))
-                    line = "%i 0 %s %i" % (symbolnr, feature_string, label)
-                    print(line, file=f)
-            command = "pfile_create -i %s -f %i -l 1 -o %s" % \
-                      (input_filename, feature_count, output_filename)
-            logging.info(command)
-            os.system(command)
-            # Clean up
-            os.remove(input_filename)
+            create_pfile(output_filename, feature_count, [(x, 0)], "tmp.txt")
         elif "model" in target_folder:
             logging.info("Create running model...")
             model_src = get_latest_model(target_folder, "model")
